pub async fn insert_best_effort(pool: &PgPool, report: &NewErrorReport)Expand description
insert for a report that must never affect its caller: a failure to get a connection quickly
or to insert is only logged.
pub async fn insert_best_effort(pool: &PgPool, report: &NewErrorReport)insert for a report that must never affect its caller: a failure to get a connection quickly
or to insert is only logged.